The following tasks implement motor paradigms:

- [Reaching1D](../envs.md#neurogym.envs.native.reaching.Reaching1D)
- [Reaching1DWithSelfDistraction](../envs.md#neurogym.envs.native.reaching.Reaching1DWithSelfDistraction)
